==> 0.3.10.tar.gz: leenooks/resources/themes/adminlte/views/layouts/partials/htmlheader.blade.php <==
<head>
	<meta charset="UTF-8">
	<meta http-equiv="X-UA-Compatible" content="IE=edge">
	<title>{{ config('app.name') }} - @yield('htmlheader_title', 'Your title here')</title>
	<meta content='width=device-width, initial-scale=1, maximum-scale=1, user-scalable=no' name='viewport'>
	<!-- CSRF Token -->
	<meta name="csrf-token" content="{{ csrf_token() }}">

	<link rel="stylesheet" href="{{ asset('/css/app.css') }}">

	<!-- Font Awesome Icons -->
	<link rel="stylesheet" href="{{ asset('/plugin/font-awesome/css/font-awesome.min.css') }}">
	<!-- IonIcons -->
	<link rel="stylesheet" href="{{ request()->getScheme() }}://code.ionicframework.com/ionicons/2.0.1/css/ionicons.min.css">
	<!-- Theme style -->
	<link rel="stylesheet" href="{{ asset('/css/adminlte.min.css') }}">
	<!-- Google Font: Source Sans Pro -->
	<link href="{{ request()->getScheme() }}://fonts.googleapis.com/css?family=Source+Sans+Pro:300,400,400i,700" rel="stylesheet">
	@if(file_exists('css/social.css'))
		<!-- Social Logins -->
		<link rel="stylesheet" href="{{ asset('/css/social.css') }}">
	@endif
	@if(file_exists('css/print.css'))
		<!-- Printing Modifications -->
		<link rel="stylesheet" href="{{ asset('/css/print.css') }}">
	@endif

	<!-- HTML5 Shim and Respond.js IE8 support of HTML5 elements and media queries -->
	<!-- WARNING: Respond.js doesn't work if you view the page via file:// -->
	<!--[if lt IE 9]>
		<script src="https://oss.maxcdn.com/html5shiv/3.7.2/html5shiv.min.js"></script>
		<script src="https://oss.maxcdn.com/respond/1.4.2/respond.min.js"></script>
	<![endif]-->

	<script>
		//See https://laracasts.com/discuss/channels/vue/use-trans-in-vuejs
		window.trans =
		@php
			// @todo Cache this processing
			// copy all translations from /resources/lang/CURRENT_LOCALE/* to global JS variable
			$lang_files = File::files(resource_path() . '/lang/' . App::getLocale());
			$trans = [];
			foreach ($lang_files as $f) {
				$filename = pathinfo($f)['filename'];
				$trans[$filename] = trans($filename);
			}
			$trans['adminlte_lang_message'] = trans('adminlte_lang::message');
			echo json_encode($trans);
		@endphp
	</script>

	<!-- STYLESHEETS -->
	{!! Asset::styles() !!}

	@if(file_exists('css/fixes.css'))
	<!-- CSS Fixes -->
		<link rel="stylesheet" href="{{ asset('/css/fixes.css') }}">
	@endif
</head>

==> 7.1.0.tar.gz: leenooks/resources/themes/adminlte/views/layouts/partials/htmlheader.blade.php <==
<head>
	<meta charset="UTF-8">
	<meta http-equiv="X-UA-Compatible" content="IE=edge">
	<title>{{ config('app.name') }} - @yield('htmlheader_title','Your title here')</title>
	<meta content='width=device-width, initial-scale=1, maximum-scale=1, user-scalable=no' name='viewport'>
	<!-- CSRF Token -->
	<meta name="csrf-token" content="{{ csrf_token() }}">

	<link rel="stylesheet" href="{{ asset('/css/app.css') }}">

	<!-- Font Awesome Icons -->
	<link rel="stylesheet" href="{{ asset('//use.fontawesome.com/releases/v5.13.0/css/all.css') }}">
	<link rel="stylesheet" href="{{ asset('//use.fontawesome.com/releases/v5.13.0/css/v4-shims.css') }}">

	<!-- Google Font: Source Sans Pro -->
	<link href="https://fonts.googleapis.com/css2?family={{ str_replace(' ','+',config('app.font') ?: 'IBM Plex Sans') }}:wght@300&display=swap" rel="stylesheet">

	@if(file_exists('css/social.css'))
		<!-- Social Logins -->
		<link rel="stylesheet" href="{{ asset('/css/social.css') }}">
	@endif
	@if(file_exists('css/print.css'))
		<!-- Printing Modifications -->
		<link rel="stylesheet" href="{{ asset('/css/print.css') }}">
	@endif

	<!-- HTML5 Shim and Respond.js IE8 support of HTML5 elements and media queries -->
	<!-- WARNING: Respond.js doesn't work if you view the page via file:// -->
	<!--[if lt IE 9]>
		<script src="https://oss.maxcdn.com/html5shiv/3.7.2/html5shiv.min.js"></script>
		<script src="https://oss.maxcdn.com/respond/1.4.2/respond.min.js"></script>
	<![endif]-->

	<!-- STYLESHEETS -->
	{!! Asset::styles() !!}

	<!-- Theme style -->
	<link rel="stylesheet" href="{{ asset('/css/adminlte.min.css') }}">

	@if(file_exists('css/fixes.css'))
		<!-- CSS Fixes -->
		<link rel="stylesheet" href="{{ asset('/css/fixes.css') }}">
	@endif

	@if(file_exists('css/custom.css'))
		<!-- Custom CSS -->
		<link rel="stylesheet" href="{{ asset('/css/custom.css') }}">
	@endif
</head>
